@@ -1,4 +1,4 @@
-﻿""" SAM macro definitions """
+""" SAM macro definitions """
 import copy
 from contextlib import suppress
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union, cast
@@ -1043,6 +1043,7 @@ class SamFunction(SamResourceMacro):
         lambda_url.TargetFunctionArn = (
             lambda_alias.get_runtime_attr("arn") if lambda_alias else lambda_function.get_runtime_attr("name")
         )
+        lambda_url.InvokeMode = function_url_config.get("InvokeMode")
         return lambda_url
 
     def _validate_function_url_params(
@@ -1220,7 +1221,7 @@ class SamApi(SamResourceMacro):
     }
 
     @cw_timer
-    def to_cloudformation(self, **kwargs):  # type: ignore[no-untyped-def]
+    def to_cloudformation(self, **kwargs) -> List[Resource]:  # type: ignore[no-untyped-def]
         """Returns the API Gateway RestApi, Deployment, and Stage to which this SAM Api corresponds.
 
         :param dict kwargs: already-converted resources that may need to be modified when converting this \
@@ -1228,7 +1229,6 @@ class SamApi(SamResourceMacro):
         :returns: a list of vanilla CloudFormation Resources, to which this Function expands
         :rtype: list
         """
-        resources = []
 
         intrinsics_resolver = kwargs["intrinsics_resolver"]
         self.BinaryMediaTypes = intrinsics_resolver.resolve_parameter_refs(self.BinaryMediaTypes)
@@ -1276,29 +1276,7 @@ class SamApi(SamResourceMacro):
             always_deploy=self.AlwaysDeploy,
         )
 
-        (
-            rest_api,
-            deployment,
-            stage,
-            permissions,
-            domain,
-            basepath_mapping,
-            route53,
-            usage_plan_resources,
-        ) = api_generator.to_cloudformation(redeploy_restapi_parameters, route53_record_set_groups)
-
-        resources.extend([rest_api, deployment, stage])
-        resources.extend(permissions)
-        if domain:
-            resources.extend([domain])
-        if basepath_mapping:
-            resources.extend(basepath_mapping)
-        if route53:
-            resources.extend([route53])
-        # contains usage plan, api key and usageplan key resources
-        if usage_plan_resources:
-            resources.extend(usage_plan_resources)
-        return resources
+        return api_generator.to_cloudformation(redeploy_restapi_parameters, route53_record_set_groups)
 
 
 class SamHttpApi(SamResourceMacro):
@@ -1417,6 +1395,7 @@ class SamSimpleTable(SamResourceMacro):
 
     resource_type = "AWS::Serverless::SimpleTable"
     property_types = {
+        "PointInTimeRecoverySpecification": PassThroughProperty(False),
         "PrimaryKey": PropertyType(False, dict_of(IS_STR, IS_STR)),
         "ProvisionedThroughput": PropertyType(False, dict_of(IS_STR, one_of(IS_INT, IS_DICT))),
         "TableName": PropertyType(False, one_of(IS_STR, IS_DICT)),
@@ -1424,6 +1403,7 @@ class SamSimpleTable(SamResourceMacro):
         "SSESpecification": PropertyType(False, IS_DICT),
     }
 
+    PointInTimeRecoverySpecification: Optional[PassThrough]
     PrimaryKey: Optional[Dict[str, str]]
     ProvisionedThroughput: Optional[Dict[str, Any]]
     TableName: Optional[Intrinsicable[str]]
@@ -1459,6 +1439,9 @@ class SamSimpleTable(SamResourceMacro):
         dynamodb_table.AttributeDefinitions = [primary_key]
         dynamodb_table.KeySchema = [{"AttributeName": primary_key["AttributeName"], "KeyType": "HASH"}]
 
+        if self.PointInTimeRecoverySpecification:
+            dynamodb_table.PointInTimeRecoverySpecification = self.PointInTimeRecoverySpecification
+
         if self.ProvisionedThroughput:
             dynamodb_table.ProvisionedThroughput = self.ProvisionedThroughput
         else:
